@@ -1,19 +1,20 @@
-/* Aisleriot - cscmi.h
+/* AisleRiot - cscmi.h
  * Copyright (C) 1998 Jonathan Blandford <jrb@mit.edu>
  *
- * This game is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This game is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2, or (at your option)
+ * any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+ * USA
  */
 
 #include "cscmi.h"
@@ -127,6 +128,11 @@ SCM scm_get_vert_start()
 {
   return gh_long2scm(get_vert_start());
 }
+SCM scm_set_statusbar_message(SCM message)
+{
+  gnome_appbar_clear_stack (GNOME_APPBAR (GNOME_APP (app)->statusbar));
+  gnome_appbar_push (GNOME_APPBAR(GNOME_APP (app)->statusbar), _(gh_scm2newstr(message,NULL)));
+}
 
 SCM scm_set_surface_layout(SCM surface) 
 {
@@ -182,7 +188,6 @@ SCM scm_set_cards(SCM scm_slot_id, SCM new_cards)
 
   return SCM_BOOL_T;
 }
-
 SCM scm_set_lambda(SCM start_game_lambda, 
 		   SCM pressed_lambda, 
 		   SCM released_lambda, 
@@ -257,6 +262,7 @@ void cscm_init ()
   gh_new_procedure0_0("get-vert-offset", scm_get_vert_offset);
   gh_new_procedure0_0("get-horiz-start", scm_get_horiz_start);
   gh_new_procedure0_0("get-vert-start", scm_get_vert_start);
+  gh_new_procedure1_0("set-statusbar-message", scm_set_statusbar_message);
   gh_new_procedure1_0("set-surface-layout", scm_set_surface_layout);
   gh_new_procedure0_0("reset-surface", scm_reset_surface);
   gh_new_procedure1_0("add-slot", scm_add_slot);
