@@ -1,13 +1,33 @@
+/* AisleRiot - dialog.c
+ * Copyright (C) 1998 Jonathan Blandford <jrb@mit.edu>
+ *
+ * This game is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2, or (at your option)
+ * any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+ * USA
+ */
+
 #include <stdlib.h>
 #include <guile/gh.h>
 #include <dirent.h>
+#include "config.h"
 #include "gnome.h"
 #include "cscmi.h"
 #include "sol.h"
 #include "menu.h"
 #include "dialog.h"
 #include "draw.h"
-
+static GtkWidget *hint_dlg = NULL;
 void show_game_over_dialog() {
   GtkWidget* dialog;
   gchar* message;
@@ -23,6 +43,7 @@ void show_game_over_dialog() {
   dialog = gnome_message_box_new (message, GNOME_MESSAGE_BOX_QUESTION,
 				  _("New Game"), GNOME_STOCK_BUTTON_CANCEL, 
 				  NULL);
+  gnome_dialog_set_parent (GNOME_DIALOG (dialog), GTK_WINDOW (app));
   gnome_dialog_set_default ( GNOME_DIALOG (dialog), 0 );
   if (gnome_dialog_run (GNOME_DIALOG (dialog)) == 0) 
     new_game (NULL, NULL);
@@ -68,6 +89,8 @@ void show_select_game_dialog()
 				    NULL );
     gnome_dialog_set_default ( GNOME_DIALOG (dialog), 0 );
 
+    gnome_dialog_set_parent ( GNOME_DIALOG (dialog), GTK_WINDOW (app) );
+
     hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
     seed_entry = gtk_entry_new ();
     label = gtk_label_new(_("Seed"));
@@ -129,6 +152,11 @@ void show_select_game_dialog()
 
   gnome_dialog_run (GNOME_DIALOG (dialog));
 }
+static void
+hint_destroy_callback (void)
+{
+  hint_dlg = NULL;
+}
 
 void show_hint_dialog() 
 {
@@ -147,7 +175,8 @@ void show_hint_dialog()
       switch (gh_scm2int(gh_car(hint))) {
 
       case 0:
-	gmessage = g_string_new (gh_scm2newstr(gh_cadr(hint),NULL));
+        /* This is discouraged, as it makes I18N a nightmare */
+	gmessage = g_string_new (_(gh_scm2newstr(gh_cadr(hint),NULL)));
 	break;
 
       case 1:
@@ -187,8 +216,19 @@ void show_hint_dialog()
     }
   }
 
-  /* Respects user prefs on status bar for hints: */
-  gnome_app_message (GNOME_APP (app), gmessage->str);
+  if (hint_dlg) {
+   /* I _think_ that ok_dialogs are closed automatically on ok being pressed */
+   /*gtk_widget_unref (hint_dlg);*/
+	  
+  }
+
+  hint_dlg = gnome_ok_dialog_parented(gmessage->str,GTK_WINDOW(app));
+  if (hint_dlg) {
+	  gtk_signal_connect (GTK_OBJECT (hint_dlg),
+			      "destroy",
+			      (GtkSignalFunc) hint_destroy_callback,
+			      NULL);
+  }
 }
 
 GtkWidget *
@@ -231,6 +271,8 @@ void show_preferences_dialog ()
 
   if (!property_box) {
     property_box = gnome_property_box_new ();
+
+    gnome_dialog_set_parent (GNOME_DIALOG (property_box), GTK_WINDOW (app));
   
     deck_edit = gdk_card_deck_options_edit_new 
       (GTK_NOTEBOOK (GNOME_PROPERTY_BOX (property_box)->notebook));
@@ -299,6 +341,8 @@ void show_rules_options_dialog ()
   
   if (!option_dialog && gh_scm2bool(options)) {
     option_dialog = gnome_property_box_new ();
+
+    gnome_dialog_set_parent (GNOME_DIALOG (option_dialog), GTK_WINDOW (app));
  
     option_page = get_option_page(option_dialog);
 
