@@ -1,19 +1,20 @@
-/* Aisleriot - events.c
+/* AisleRiot - events.c
  * Copyright (C) 1998 Jonathan Blandford <jrb@mit.edu>
  *
- * This game is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This game is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2, or (at your option)
+ * any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+ * USA
  */
 
 #include "events.h"
@@ -25,7 +26,8 @@
 
 /* Defining SINGLE_ACTION prevents scheme from being called twice when
  * a double click occurs but delays the single_click action by 250ms */
-#define SINGLE_ACTION 
+/*#define SINGLE_ACTION */
+/* I don't like this, so it's commented out -jrb */
 
 /* Button press statuses */
 enum {
@@ -46,6 +48,7 @@ void end_of_game_test() {
     if (game_over) {
       timer_stop ();
       game_won = gh_scm2bool (gh_call0 (game_data->winning_game_lambda));
+      refresh_screen ();
       show_game_over_dialog ();
     }
   }  
@@ -127,22 +130,21 @@ gint button_press_event (GtkWidget *widget, GdkEventButton *event, void *d)
   /* ignore the gdk synthetic click events */
   if (event->type != GDK_BUTTON_PRESS)
     return TRUE;
-
+  if (event->button == 2)
+    return TRUE;
+  
 #ifndef SINGLE_ACTION
   if (gdk_time_get() > first_press + dbl_click_time)
     press_data->status = STATUS_NONE;
 #endif
-
   slot_pressed(event->x, event->y, &hslot, &cardid);
 
   if (!hslot)
     return TRUE;
-
   press_data->xoffset = event->x;
   press_data->yoffset = event->y;
   press_data->hslot = hslot;
   press_data->cardid = cardid;
-
   if (event->button == 1) {
     if (press_data->status == STATUS_CLICK) {
       /* double click */
@@ -150,8 +152,15 @@ gint button_press_event (GtkWidget *widget, GdkEventButton *event, void *d)
 #ifdef SINGLE_ACTION
       gtk_timeout_remove (timer_click);
 #endif
-      gh_call1 (game_data->button_double_clicked_lambda, 
-		gh_long2scm (hslot->id));
+      gh_call2 (gh_eval_str ("record-move"), gh_long2scm (-1),
+		SCM_EOL);
+      if (gh_scm2bool (gh_call1 (game_data->button_double_clicked_lambda, 
+				 gh_long2scm (hslot->id))))
+	      gh_call0 (gh_eval_str ("end-move"));
+      else
+	      gh_call0 (gh_eval_str ("discard-move"));
+      refresh_screen ();
+      end_of_game_test ();
       return TRUE;
     }
     else {
@@ -163,7 +172,7 @@ gint button_press_event (GtkWidget *widget, GdkEventButton *event, void *d)
 #endif
     }
   }
-  else if (event->button == 3 && cardid > 0) {
+  else if (event->button == 3 && cardid > 0 && press_data->status == STATUS_NONE) {
     hcard_type card = g_list_nth(hslot->cards, cardid - 1)->data;
     
     if (card->direction == UP) {      
@@ -188,6 +197,9 @@ gint button_press_event (GtkWidget *widget, GdkEventButton *event, void *d)
 
 gint button_release_event (GtkWidget *widget, GdkEventButton *event, void *d)
 {
+  if (event->button == 2)
+    return TRUE;
+
   switch (press_data->status) {
   case STATUS_IS_DRAG:
     press_data->status = STATUS_NONE;
@@ -205,8 +217,13 @@ gint button_release_event (GtkWidget *widget, GdkEventButton *event, void *d)
   case STATUS_NOT_DRAG:
     press_data->status = STATUS_CLICK;
 #ifndef SINGLE_ACTION
-    gh_call1 (game_data->button_clicked_lambda, 
-	      gh_long2scm (press_data->hslot->id));
+    gh_call2 (gh_eval_str ("record-move"), gh_long2scm (-1),
+	      SCM_EOL);
+    if (gh_scm2bool (gh_call1 (game_data->button_clicked_lambda, 
+			       gh_long2scm (press_data->hslot->id))))
+	    gh_call0 (gh_eval_str ("end-move"));
+    else
+	    gh_call0 (gh_eval_str ("discard-move"));
     refresh_screen();
     end_of_game_test();
 #endif
@@ -221,7 +238,9 @@ gint button_release_event (GtkWidget *widget, GdkEventButton *event, void *d)
 
 gint motion_notify_event (GtkWidget *widget, GdkEventMotion *event)
 {
+/*g_print ("move\n");*/
   if (press_data->status == STATUS_IS_DRAG) {
+/*g_print ("keep movin\n");*/
     gdk_window_move(press_data->moving_cards,  
 		    event->x - press_data->xoffset,
 		    event->y - press_data->yoffset);
@@ -233,6 +252,7 @@ gint motion_notify_event (GtkWidget *widget, GdkEventMotion *event)
     hslot_type hslot = press_data->hslot;
     GList* glist = g_list_nth(hslot->cards, press_data->cardid - 1); 
     SCM cardlist = SCM_EOL;
+/*g_print ("maybe move\n");*/
     
     for (; glist; glist = glist->next)
       cardlist = gh_cons(make_card((hcard_type)glist->data), cardlist);
