@@ -1,4 +1,4 @@
-;;; freecell.scm -- Free Cell game for Aisleriot.
+;;; freecell.scm -- Free Cell game for AisleRiot.
 
 ;; Copyright (C) 1998 Changwoo Ryu
 
@@ -177,9 +177,11 @@
 	 (if (empty-slot? homecell-id)
 	     ; Put an Ace into an empty homecell
 	     (and (eq? (get-value card) ace)
+		  (add-to-score! 1)
 		  (add-card! homecell-id card))
 	     ; Put a +1 card into the homecell, whose suit is same.
 	     (and (homecell-join? (car (get-cards homecell-id)) card)
+		  (add-to-score! 1)
 		  (add-card! homecell-id card))))))
 
 (define (move-to-field card-list field-id)
@@ -295,12 +297,14 @@
   #f)
  
 (define (get-options) 
-  '(("Auto move to homecell" option-auto-move)
-    ("Move one by one" option-one-by-one)))
+  #f)
+;  '(("Auto move to homecell" option-auto-move)
+;    ("Move one by one" option-one-by-one)))
 
 (define (apply-options options) 
-  (set! option-auto-move (cadar options))
-  (set! option-auto-move (cadadr options)))
+  #f)
+;  (set! option-auto-move (cadar options))
+;  (set! option-auto-move (cadadr options)))
 
 (define (timeout) 
   ; (FIXME)
