@@ -1,19 +1,20 @@
-/* Aisleriot - sol.c
+/* AisleRiot - sol.c
  * Copyright (C) 1998 Jonathan Blandford <jrb@mit.edu>
  *
- * This game is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This game is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2, or (at your option)
+ * any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+ * USA
  */
 
 #include <config.h>
@@ -49,7 +50,7 @@ GtkObject*       card_deck;
 GdkCardDeckOptions deck_options = NULL;
 
 guint            score;
-guint            game_seconds;
+/* guint            game_seconds;*/
 guint            timeout;
 guint            seed;
 guint            n_games;
@@ -109,9 +110,9 @@ void make_title ()
 {
   char *title;
 
-  title = alloca(strlen(game_name) + 20);
+  title = alloca(strlen(game_name) + 34);
   
-  sprintf(title, "%s  ( %d )", game_name, seed);
+  sprintf(title, "AisleRiot:  %s  ( %d )", game_name, seed);
 
   gtk_window_set_title (GTK_WINDOW (app), title); 
 }
@@ -150,6 +151,11 @@ void new_game (gchar* file, guint *seedp )
     guint pos;
 
     game_file = file;
+
+    /* Although this line slows down game switching by a noticeable amount, we
+     * add it here in order to make sure all the original functions are
+     * "clean". */
+    eval_installed_file ("sol.scm");
     eval_installed_file (file);
     if(game_name) {
       sprintf(buf, "%s/%s", N_("Help"), game_name);
@@ -217,24 +223,31 @@ void set_score ()
 
 GtkWidget *time_value;
 
-void set_time () 
-{
-  char b [10];
-  sprintf (b, "%3d:%02d ", game_seconds / 60, game_seconds % 60);
-
-  gtk_label_set(GTK_LABEL(time_value), b);
-}
+/* void set_time () 
+ *{
+ *  char b [10];
+ *  sprintf (b, "%3d:%02d ", game_seconds / 60, game_seconds % 60);
+ *
+ *  gtk_label_set(GTK_LABEL(time_value), b);
+ *}
+ */
 
 gint timer_cb ()
 {
-  game_seconds++;
-  set_time();
-  if (game_seconds > timeout) {
-    timeout = 3600;
-    gh_call0(game_data->timeout_lambda);
-    end_of_game_test();
-  }
-  return game_seconds < 3599; /* give up at end of one hour */
+#if 0
+/*  game_seconds++;
+ *  set_time();
+ *  if (game_seconds > timeout) {
+ *    timeout = 3600;
+ *    gh_call0(game_data->timeout_lambda);
+ *    end_of_game_test();
+ *  }
+ *  return game_seconds < 3599; *//* give up at end of one hour */
+#endif
+  timeout = 3600;
+  gh_call0(game_data->timeout_lambda);
+  end_of_game_test();
+  return 0;	
 }
 
 guint timer_timeout = 0;
@@ -242,15 +255,22 @@ guint timer_timeout = 0;
 void timer_start ()
 {
   if (timer_timeout)
-    timer_stop();
-  game_seconds = 0;
+/*    timer_stop();
+ *  game_seconds = 0;
+ */
+  gtk_clock_stop (GTK_CLOCK (time_value));
   timeout = 3600;
-  set_time();
-  timer_timeout = gtk_timeout_add (1000, (GtkFunction) (timer_cb), NULL); 
+/*  set_time();
+ *  timer_timeout = gtk_timeout_add (1000, (GtkFunction) (timer_cb), NULL);
+ */
+  gtk_clock_set_seconds (GTK_CLOCK (time_value), 0);
+  gtk_clock_start (GTK_CLOCK (time_value));
+  timer_timeout = gtk_timeout_add (timeout * 1000, (GtkFunction) (timer_cb), NULL);
 }
 
 void timer_stop ()
 {
+  gtk_clock_stop (GTK_CLOCK (time_value));
   gtk_timeout_remove (timer_timeout);
   timer_timeout = 0;
 }
@@ -349,14 +369,14 @@ void main_prog(int argc, char *argv[])
   create_menus ();
 
   score_box = gtk_hbox_new(0, FALSE);
-  score_label = gtk_label_new (_("Score:"));
+  score_label = gtk_label_new (_("Score: "));
   gtk_box_pack_start (GTK_BOX(score_box), score_label, FALSE, FALSE, 0);
-  score_value = gtk_label_new ("     0  ");
+  score_value = gtk_label_new ("   0");
   gtk_box_pack_start (GTK_BOX(score_box), score_value, FALSE, FALSE, 0);
-  time_label = gtk_label_new (_("Time:"));
+  time_label = gtk_label_new (_("Time: "));
   gtk_box_pack_start (GTK_BOX(score_box), time_label, FALSE, FALSE, 0);
-  time_value = gtk_label_new ("  0:00 ");
-  gtk_box_pack_start (GTK_BOX(score_box), time_value, FALSE, FALSE, 0);
+  time_value = gtk_clock_new (GTK_CLOCK_INCREASING);
+  gtk_box_pack_start (GTK_BOX(score_box), time_value, FALSE, FALSE, GNOME_PAD_SMALL);
 
   gtk_widget_show (score_label);
   gtk_widget_show (score_value);
@@ -364,7 +384,7 @@ void main_prog(int argc, char *argv[])
   gtk_widget_show (time_value);
   gtk_widget_show (score_box);
 
-  status_bar = gnome_appbar_new (FALSE, TRUE, TRUE);
+  status_bar = gnome_appbar_new (FALSE, TRUE, FALSE);
   gtk_box_pack_end (GTK_BOX(status_bar), score_box, FALSE, FALSE, 0);
   gnome_app_set_statusbar (GNOME_APP (app), status_bar);
 
