@@ -1,19 +1,20 @@
-; Aisleriot - sol.scm
+; AisleRiot - sol.scm
 ; Copyright (C) 1998 Jonathan Blandford <jrb@mit.edu>
 ;
-; This game is free software; you can redistribute it and/or
-; modify it under the terms of the GNU Library General Public
-; License as published by the Free Software Foundation; either
-; version 2 of the License, or (at your option) any later version.
+; This game is free software; you can redistribute it and/or modify
+; it under the terms of the GNU General Public License as published by
+; the Free Software Foundation; either version 2, or (at your option)
+; any later version.
 ;
-; This library is distributed in the hope that it will be useful,
+; This program is distributed in the hope that it will be useful,
 ; but WITHOUT ANY WARRANTY; without even the implied warranty of
-; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-; Library General Public License for more details.
+; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+; GNU General Public License for more details.
 ;
-; You should have received a copy of the GNU Library General Public
-; License along with this library; if not, write to the Free
-; Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+; You should have received a copy of the GNU General Public License
+; along with this program; if not, write to the Free Software
+; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+; USA
 
 ;; Constants:
 
@@ -21,6 +22,7 @@
 (define queen 12)
 (define king 13)
 (define ace 1)
+(define joker 0)
 
 (define club 0)
 (define diamond 1)
@@ -49,6 +51,7 @@
   (set! VERTPOS (get-vert-start))
   (set! IN-GAME #f)
   (set! MOVE '())
+  (set-statusbar-message "")
   (set! HISTORY '()))
 
 ; create a 52 card deck (puts list of cards into DECK)
@@ -57,12 +60,32 @@
       (set! DECK (make-standard-deck-list-ace-high 2 club))
       (set! DECK (make-standard-deck-list-ace-low ace club))))
 
+; create a 54 card deck with 2 jokers.
+(define (make-joker-deck)
+  (if (= ace 14)
+     (set! DECK (cons (make-card joker club) (cons (make-card joker diamond) 
+		 (make-standard-deck-list-ace-high 2 club))))
+     (set! DECK (cons (make-card joker club) (cons (make-card joker diamond) 
+		 (make-standard-deck-list-ace-low ace club))))))
+     
 ; create a double deck of 104 cards (puts list of cards into DECK)
 (define (make-standard-double-deck)
   (if (= ace 14)
       (set! DECK (append (make-standard-deck-list-ace-high 2 club) (make-standard-deck-list-ace-high 2 club)))
       (set! DECK (append (make-standard-deck-list-ace-low ace club) (make-standard-deck-list-ace-low ace club)))))
 
+; makes a deck from init-value to kings
+(define (make-deck-list-ace-low init-value value suit)
+   (if (eq? king value)
+      (if (eq? spade suit)
+	  (list (make-card king spade))
+	  (cons (make-card value suit) 
+		(make-deck-list-ace-low 
+		 init-value init-value (+ 1 suit))))
+      (cons (make-card value suit) 
+	    (make-deck-list-ace-low init-value (+ 1 value) suit))))
+
+
 ; shuffle the card list in DECK
 (define (shuffle-deck)
   (let* ((vec (list->vector DECK))
@@ -165,17 +188,19 @@
       (and (< FLIP-COUNTER flip-limit)
 	   (set! FLIP-COUNTER (+ 1 FLIP-COUNTER))
 	   (flip-deck stock-slot waste-slot))
-      (let loop ((i (if (null? rest) 1 (car rest))))
-	(and (> i 0)
-	     (not (empty-slot? stock-slot))
-	     (add-card! waste-slot (flip-card (remove-card stock-slot)))
-	     (loop (- i 1))))))
+      (or (let loop ((i (if (null? rest) 1 (car rest))))
+	    (and (> i 0)
+		 (not (empty-slot? stock-slot))
+		 (add-card! waste-slot (flip-card (remove-card stock-slot)))
+		 (loop (- i 1))))
+	  #t)))
 
 ; turn the cards in the waste slot over and add them to the stock-slot.
 (define (flip-deck stock-slot waste-slot)
   (and (not (empty-slot? waste-slot))
        (add-card! stock-slot (flip-card (remove-card waste-slot)))
-       (flip-deck stock-slot waste-slot)))
+       (or (flip-deck stock-slot waste-slot)
+	   #t)))
 
 ;; Procedures for manipulating cards:
 
@@ -231,6 +256,13 @@
 (define (is-black? card)
   (eq? black (get-color card)))
 
+(define (is-joker? card)
+  (= (get-value card) joker))
+
+(define (set-ace-low)  (set! ace 1))
+
+(define (set-ace-high) (set! ace 14))
+
 ; use to compare two cards when aces are treated as high:
 (define (ace-high-order value)
   (remainder (+ 11 value) 13))
@@ -273,25 +305,22 @@
 	((eq? suit diamond) "diamonds")
 	(#t "Unknown suit")))
 
+(define (get-joker-name card) 
+  (if (is-black? card) "black joker" "red joker"))
+
 (define (get-name card)
-  (string-append (get-value-name (get-value card)) 
-		 " of "
-		 (get-suit-name (get-suit card))))
+  (if (is-joker? card)
+      (get-joker-name card)
+      (string-append (get-value-name (get-value card)) 
+		     " of "
+		     (get-suit-name (get-suit card)))))
 
-;; Deprecated procedures:
-; probably better to stick with ace = 1 to avoid confusion.
-(define (set-ace-low)  (set! ace 1))
-(define (set-ace-high) (set! ace 14))
-
-; use add-cards! instead - the name of this procedure is misleading
 (define (move-n-cards! start-slot end-slot cards)
   (add-cards! end-slot cards))
 
-; you probably do not want to use this as it throws away the cards:
 (define (remove-n-cards slot-id n)
   (set-cards! slot-id (nthcdr n (get-cards slot-id))))
 
-; use deal-cards instead, it is more consistent with the rest of the API.
 (define (deal-cards-from-deck deck slot-list)
   (if (not (null? slot-list))
       (begin 
@@ -304,70 +333,10 @@
 	(add-card! (car slot-list) (make-visible (car deck)))
 	(deal-cards-face-up-from-deck (cdr deck) (cdr slot-list)))))
 
-;; INTERNAL procedures
-; The procedures in the rest of this file should not be used by games!!!
-; Perhaps they should be in a separate file ???
 
-; global variables
-(define FLIP-COUNTER 0)
-(define SLOTS 0)
-(define HORIZPOS 0)
-(define VERTPOS 0)
-(define MOVE '())
-(define HISTORY '())
-(define FUTURE '())
-(define IN-GAME #f)
-(define MOVE-MODE '())
-
-; called from C:
-(define (start-game)
-  (set! IN-GAME #t))
-
-; called from C:
-(define (end-move)
-  (set! HISTORY (cons MOVE HISTORY))
-  (set! FUTURE '())
-  (set! MOVE '()))
-
-; called from C:
-(define (undo)
-  (if (not (null? HISTORY))
-      (let ((move (car HISTORY)))
-	(set! MOVE-MODE 'undo)
-	(eval (cons 'begin move))
-	(set! FUTURE (cons move FUTURE)) 
-	(set! HISTORY (cdr HISTORY))))) 
-	
-; called from C:
-(define (redo)
-  (if (not (null? FUTURE))
-      (let ((move (car FUTURE)))
-	(set! MOVE-MODE 'redo)
-	(eval (cons 'begin (reverse move)))
-	(set! HISTORY (cons move HISTORY)) 
-	(set! FUTURE (cdr FUTURE))))) 
-
-(define (sub-move slot-id cards1 cards2)
-  (if (eq? MOVE-MODE 'redo)
-      (set-cards-c! slot-id cards1)
-      (set-cards-c! slot-id cards2)))
-
-; called from C:
-(define (record-move slot-id new_cards old_cards)
-  (set! MOVE (cons (list 'sub-move 
-			 slot-id 
-			 (list 'quote new_cards)
-			 (list 'quote old_cards)) MOVE)))
-
-; called from C:
-(define (discard-move)
-  (set! MOVE '()))
-
-; Used directly by some naughty code so we have to do redo / undo at
-; this level until that code is changed to use the proper API:
 (define (set-cards! slot-id new_cards)
-  (if IN-GAME 
-      (record-move slot-id new_cards (get-cards slot-id)))
+;  (if IN-GAME 
+;      (record-move slot-id new_cards (get-cards slot-id)))
   (set-cards-c! slot-id new_cards))
 
 (define (make-card value suit)
@@ -415,6 +384,89 @@
   (set! HORIZPOS (get-horiz-start))
   (set! VERTPOS (+ VERTPOS (get-vert-offset))))
 
+(define (register-undo-function function data)
+  (set! MOVE (cons '(function data) (cdr MOVE))))
+
 ; common lisp procedure not provided in guile 1.3
 (define (nthcdr n lst)
   (if (zero? n) lst (nthcdr (+ -1 n) (cdr lst))))
+
+;; INTERNAL procedures
+
+; global variables
+(define FLIP-COUNTER 0)
+(define SLOTS 0)
+(define HORIZPOS 0)
+(define VERTPOS 0)
+(define MOVE '())
+(define HISTORY '())
+(define FUTURE '())
+(define IN-GAME #f)
+
+; called from C:
+(define (start-game)
+  (set! IN-GAME #t))
+
+; called from C:
+(define (end-move)
+  (if (not (= 0 (length MOVE)))
+      (begin
+	(set! HISTORY (cons MOVE HISTORY))
+	(set! FUTURE '())
+	(set! MOVE '()))))
+
+(define (return-cards card-positions slot-id)
+  (and (not (= 0 (length card-positions)))
+       (set-cards! slot-id (car card-positions))
+       (return-cards (cdr card-positions) (+ 1 slot-id))))
+
+(define (give-status-message)
+  #t)
+
+(define (eval-move move)
+  (return-cards (caddr move) 0)
+  ((car move) (cadr move))
+  (give-status-message))
+
+; called from C:
+(define (undo)
+  (and (not (null? HISTORY))
+       (record-move -1 '())
+       (eval-move (car HISTORY))
+       (set! FUTURE (cons MOVE FUTURE))
+       (set! HISTORY (cdr HISTORY))
+       (set! MOVE '())))
+
+; called from C:
+(define (redo)
+  (and (not (null? FUTURE))
+       (record-move -1 '())
+       (eval-move (car FUTURE))
+       (set! HISTORY (cons MOVE HISTORY))
+       (set! FUTURE (cdr FUTURE))
+       (set! MOVE '())))
+
+(define (undo-func data)
+  (set-score! (car data))
+  (set! FLIP-COUNTER (cadr data)))
+;(register-undo-function undo-func '(score FLIP-COUNTER))
+	     
+(define (snapshot-board slot-id moving-slot old-cards)
+  (cond ((>= slot-id SLOTS)
+	 '())
+	((= slot-id moving-slot)
+	 (cons old-cards 
+	       (snapshot-board (+ 1 slot-id) moving-slot old-cards)))
+	(#t
+	 (cons (get-cards slot-id) 
+	       (snapshot-board (+ 1 slot-id) moving-slot old-cards)))))
+
+; called from C:
+(define (record-move slot-id old-cards)
+  (set! MOVE (list undo-func 
+		   (list (get-score) FLIP-COUNTER)
+		   (snapshot-board 0 slot-id old-cards))))
+
+; called from C:
+(define (discard-move)
+  (set! MOVE '()))
