@@ -50,6 +50,7 @@ extern int card_image_top_height(void); /* In card-draw.c */
 #define FIELD_HEIGHT card_image_top_height() * 14
 
 static GtkWidget *main_window;
+static GtkWidget *mb;
 
 static GtkWidget *freecell_drawing_areas[4];
 static GtkWidget *destination_drawing_areas[4];
@@ -308,7 +309,8 @@ refresh_all (void)
 void
 callback_restart (GtkWidget *widget, GdkEvent *event)
 {
-   GtkWidget *mb;
+  if (mb)
+	  return;
 
   if (!stalled
       && freecellgame
@@ -319,12 +321,13 @@ callback_restart (GtkWidget *widget, GdkEvent *event)
 				  GNOME_STOCK_BUTTON_YES,
 				  GNOME_STOCK_BUTTON_NO,
 				  NULL);
-      GTK_WINDOW(mb)->position = GTK_WIN_POS_MOUSE;
-      gtk_window_set_modal(GTK_WINDOW (mb), TRUE);
+/*    GTK_WINDOW(mb)->position = GTK_WIN_POS_MOUSE; */
+/*    gtk_window_set_modal(GTK_WINDOW (mb), TRUE); */
       gtk_signal_connect_object(GTK_OBJECT(mb),
 				"clicked",
 				GTK_SIGNAL_FUNC(callback_restart_lose),
 				NULL);
+      gnome_dialog_set_parent (GNOME_DIALOG (mb), GTK_WINDOW (main_window));
       gtk_widget_show (mb);
     }
   else
@@ -340,6 +343,8 @@ callback_restart_lose (GtkWidget *widget, gpointer data)
       score_add_lose ();
       callback_restart_really ();
     }
+
+  mb = NULL;
 }
 
 static void
@@ -400,7 +405,9 @@ callback_new_with_seed_really (void)
 			     GNOME_STOCK_BUTTON_OK,
 			     GNOME_STOCK_BUTTON_CANCEL, NULL);
 
-  label = gtk_label_new (_("Enter the seed."));
+  gnome_dialog_set_parent (GNOME_DIALOG (dialog), GTK_WINDOW (main_window));
+
+  label = gtk_label_new (_("Seed value:"));
   gtk_box_pack_start_defaults (GTK_BOX(GNOME_DIALOG(dialog)->vbox), label);
   gtk_widget_show (label);
   
@@ -426,13 +433,15 @@ callback_new_with_seed_with_lose (GtkWidget *widget, gpointer data)
       score_add_lose();
       callback_new_with_seed_really();
     }
+  mb = NULL;
 }
 
 
 void
 callback_new_with_seed (GtkWidget *widget, GdkEvent *event)
 {
-  GtkWidget *mb;
+  if (mb)
+	  return;
 
   if (!stalled
       && freecellgame
@@ -443,12 +452,13 @@ callback_new_with_seed (GtkWidget *widget, GdkEvent *event)
 				  GNOME_STOCK_BUTTON_YES,
 				  GNOME_STOCK_BUTTON_NO,
 				  NULL);
-      GTK_WINDOW(mb)->position = GTK_WIN_POS_MOUSE;
-      gtk_window_set_modal(GTK_WINDOW(mb), TRUE);
+/*    GTK_WINDOW(mb)->position = GTK_WIN_POS_MOUSE; */
+/*    gtk_window_set_modal(GTK_WINDOW(mb), TRUE); */
       gtk_signal_connect_object(GTK_OBJECT(mb),
 				"clicked",
 				GTK_SIGNAL_FUNC(callback_new_with_seed_with_lose),
 				NULL);
+      gnome_dialog_set_parent (GNOME_DIALOG (mb), GTK_WINDOW (main_window));
       gtk_widget_show (mb);
     }
   else
@@ -491,13 +501,15 @@ callback_new_with_lose (GtkWidget *widget, gpointer data)
       score_add_lose();
       callback_new_really();
     }
+  mb = NULL;
 }
 
 
 void
 callback_new (GtkWidget *widget, GdkEvent *event)
 {
-  GtkWidget *mb;
+  if (mb)
+	  return;
 
   if (!stalled
       && freecellgame
@@ -508,12 +520,13 @@ callback_new (GtkWidget *widget, GdkEvent *event)
 				  GNOME_STOCK_BUTTON_YES,
 				  GNOME_STOCK_BUTTON_NO,
 				  NULL);
-      GTK_WINDOW(mb)->position = GTK_WIN_POS_MOUSE;
-      gtk_window_set_modal(GTK_WINDOW(mb), TRUE);
+/*    GTK_WINDOW(mb)->position = GTK_WIN_POS_MOUSE; */
+/*    gtk_window_set_modal(GTK_WINDOW(mb), TRUE); */
       gtk_signal_connect_object(GTK_OBJECT(mb),
 				"clicked",
 				GTK_SIGNAL_FUNC(callback_new_with_lose),
 				NULL);
+      gnome_dialog_set_parent (GNOME_DIALOG (mb), GTK_WINDOW (main_window));
       gtk_widget_show (mb);
     }
   else
@@ -548,6 +561,8 @@ callback_option (GtkWidget *widget, GdkEvent *event)
 
   dialog = option_dialog ();
 
+  gnome_dialog_set_parent (GNOME_DIALOG (dialog), GTK_WINDOW (main_window));
+
   gtk_widget_show (dialog);
 }
 
@@ -557,12 +572,13 @@ callback_rule (GtkWidget *widget, GdkEvent *event)
 {
   GtkWidget *mb;
 
-  mb = gnome_message_box_new (_("Sorry, this feature is not implemented (yet)."),
+  mb = gnome_message_box_new (_("Sorry, this feature is not (yet) implemented."),
 			      GNOME_MESSAGE_BOX_INFO,
 			      GNOME_STOCK_BUTTON_OK,
 			      NULL);
-  GTK_WINDOW(mb)->position = GTK_WIN_POS_MOUSE;
+  /*GTK_WINDOW(mb)->position = GTK_WIN_POS_MOUSE;*/
   gtk_window_set_modal (GTK_WINDOW(mb), TRUE);
+  gnome_dialog_set_parent (GNOME_DIALOG (mb), GTK_WINDOW (main_window));
   gtk_widget_show (mb);
 }
 
@@ -583,14 +599,16 @@ callback_exit_with_lose (GtkWidget *widget, gpointer data)
       score_add_lose();
       callback_exit_really();
     }
+  mb = NULL;
 }
 
 
 void
 callback_exit (GtkWidget *widget, GdkEvent *event)
 {
-  GtkWidget *mb;
-  
+  if (mb)
+	  return;
+
   if (!stalled
       && freecellgame
       && !freecellgame_is_finished(freecellgame))
@@ -601,12 +619,13 @@ callback_exit (GtkWidget *widget, GdkEvent *event)
 				  GNOME_STOCK_BUTTON_NO,
 				  NULL);
 
-      GTK_WINDOW(mb)->position = GTK_WIN_POS_MOUSE;
-      gtk_window_set_modal(GTK_WINDOW(mb), TRUE);
+/*    GTK_WINDOW(mb)->position = GTK_WIN_POS_MOUSE; */
+/*    gtk_window_set_modal(GTK_WINDOW(mb), TRUE); */
       gtk_signal_connect_object(GTK_OBJECT(mb),
 				"clicked",
 				GTK_SIGNAL_FUNC(callback_exit_with_lose),
 				NULL);
+      gnome_dialog_set_parent (GNOME_DIALOG (mb), GTK_WINDOW (main_window));
       gtk_widget_show (mb);
     }
   else
@@ -647,12 +666,13 @@ inform_invalid_move (void)
 {
   GtkWidget *mb;
 
-  mb = gnome_message_box_new (_("You can't move in that way."),
+  mb = gnome_message_box_new (_("That move is invalid."),
 			      GNOME_MESSAGE_BOX_ERROR,
 			      GNOME_STOCK_BUTTON_OK,
 			      NULL);
-  GTK_WINDOW(mb)->position = GTK_WIN_POS_MOUSE;
+  /*GTK_WINDOW(mb)->position = GTK_WIN_POS_MOUSE;*/
   gtk_window_set_modal(GTK_WINDOW(mb), TRUE);
+  gnome_dialog_set_parent (GNOME_DIALOG (mb), GTK_WINDOW (main_window));
   gtk_widget_show (mb);
 }
 
@@ -1134,13 +1154,14 @@ to_destination_auto(void)
 
   if (freecellgame_is_there_no_way(freecellgame))
     {
-      mb = gnome_message_box_new (_("Sorry, there is no card to move."),
+      mb = gnome_message_box_new (_("Sorry, there are no more valid moves."),
 				  GNOME_MESSAGE_BOX_INFO,
 				  GNOME_STOCK_BUTTON_OK,
 				  NULL);
 
-      GTK_WINDOW(mb)->position = GTK_WIN_POS_MOUSE;
+/*    GTK_WINDOW(mb)->position = GTK_WIN_POS_MOUSE; */
       gtk_window_set_modal(GTK_WINDOW(mb), TRUE);
+      gnome_dialog_set_parent (GNOME_DIALOG (mb), GTK_WINDOW (main_window));
       gtk_widget_show (mb);
       score_add_lose();
       stalled = 1;
@@ -1148,13 +1169,15 @@ to_destination_auto(void)
   
   if (freecellgame_is_finished(freecellgame))
     {
-      mb = gnome_message_box_new (_("Congraturations.  You won.\nDo you want to play again?"),
+      g_slist_free (freecellgame->history);
+      mb = gnome_message_box_new (_("Congratulations.  You won.\nDo you want to play again?"),
 				  GNOME_MESSAGE_BOX_QUESTION,
 				  GNOME_STOCK_BUTTON_YES,
 				  GNOME_STOCK_BUTTON_NO,
 				  NULL);
-      GTK_WINDOW(mb)->position = GTK_WIN_POS_MOUSE;
+/*    GTK_WINDOW(mb)->position = GTK_WIN_POS_MOUSE; */
       gtk_window_set_modal(GTK_WINDOW(mb), TRUE);
+      gnome_dialog_set_parent (GNOME_DIALOG (mb), GTK_WINDOW (main_window));
       gtk_signal_connect_object (GTK_OBJECT (mb),
 				 "clicked",
 				 GTK_SIGNAL_FUNC(callback_new_really_callback),
