@@ -1,4 +1,4 @@
-/* option.c
+/* option.c --
    Copyright (C) 1998 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and'or modify
@@ -13,21 +13,25 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+   USA */
 
-/* Written by Ryu Changwoo <cwryu@eve.kaist.ac.kr>. */
+/* Written by Changwoo Ryu <cwryu@adam.kaist.ac.kr>. */
 
 
 #include <config.h>
 #include <gnome.h>
 
-int option_inform_invalid_move;
+int option_inform_invalid_move = 0;
+int option_move_one_by_one = 0;
 
 void
 option_init (void)
 {
   option_inform_invalid_move
     = gnome_config_get_int ("/freecell/option/inform_invalid_move=1");
+  option_move_one_by_one
+    = gnome_config_get_int ("/freecell/option/move_one_by_one=0");
 }
 
 
@@ -36,6 +40,8 @@ option_write (void)
 {
   gnome_config_set_int ("/freecell/option/inform_invalid_move",
 			option_inform_invalid_move);
+  gnome_config_set_int ("/freecell/option/move_one_by_one",
+			option_move_one_by_one);
   gnome_config_sync();
 }
 
