@@ -1,3 +1,22 @@
+/* 
+ *   Gnome Nibbles: Gnome Worm Game
+ *   Written by Sean MacIsaac <sjm@acm.org>, Ian Peters <itp@gnu.org>
+ * 
+ *   This program is free software; you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation; either version 2 of the License, or
+ *   (at your option) any later version.
+ *
+ *   This program is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *   GNU General Public License for more details.
+ *
+ *   You should have received a copy of the GNU General Public License
+ *   along with this program; if not, write to the Free Software
+ *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
+
 #include <config.h>
 #include <gnome.h>
 #include <gdk/gdkkeysyms.h>
@@ -10,7 +29,7 @@
 #include "properties.h"
 #include "scoreboard.h"
 
-GnibblesWorm *worms[NUMWORMS] = { NULL, NULL, NULL, NULL };
+GnibblesWorm *worms[NUMWORMS];
 GnibblesBoni *boni = NULL;
 GnibblesWarpManager *warpmanager;
 
@@ -18,8 +37,6 @@ GdkPixmap *buffer_pixmap = NULL;
 GdkPixmap *gnibbles_pixmap = NULL;
 GdkPixmap *logo_pixmap = NULL;
 
-//gint numworms = 1;
-
 extern GtkWidget *drawing_area;
 
 extern gchar board[BOARDWIDTH][BOARDHEIGHT];
@@ -83,11 +100,6 @@ void gnibbles_load_pixmap ()
 
 	image = gdk_imlib_load_image (filename);
 	visual = gdk_imlib_get_visual ();
-	/*
-	if (visual->type != GDK_VISUAL_TRUE_COLOR) {
-		gdk_imlib_set_render_type (RT_PLAIN_PALETTE);
-	}
-	*/
 	gdk_imlib_render (image, image->rgb_width, image->rgb_height);
 	gnibbles_pixmap = gdk_imlib_move_image (image);
 
@@ -95,7 +107,7 @@ void gnibbles_load_pixmap ()
 	g_free (filename);
 
 	filename = gnome_unconditional_pixmap_file
-		("gnibbles/gnibbles_logo.png");
+		("gnibbles/gnibbles-logo.png");
 
 	if (!g_file_exists (filename)) {
 		g_print (_("Couldn't find pixmap file!\n"));
@@ -104,11 +116,6 @@ void gnibbles_load_pixmap ()
 
 	image = gdk_imlib_load_image (filename);
 	visual = gdk_imlib_get_visual ();
-	/*
-	if (visual->type != GDK_VISUAL_TRUE_COLOR) {
-		gdk_imlib_set_render_type (RT_PLAIN_PALETTE);
-	}
-	*/
 	gdk_imlib_render (image, image->rgb_width, image->rgb_height);
 	logo_pixmap = gdk_imlib_move_image (image);
 
@@ -234,22 +241,11 @@ void gnibbles_init ()
 	gnibbles_scoreboard_clear (scoreboard);
 
 	for (i = 0; i < properties->numworms; i++) {
-		worms[i] = gnibbles_worm_new (properties->wormprops[i]->color,
-				properties->wormprops[i]->up,
-				properties->wormprops[i]->down,
-				properties->wormprops[i]->left,
-				properties->wormprops[i]->right);
+		worms[i] = gnibbles_worm_new (i);
 		gnibbles_scoreboard_register (scoreboard, worms[i]);
 	}
 
 	gnibbles_scoreboard_update (scoreboard);
-	/*
-	worms[0] = gnibbles_worm_new (WORMCYAN, GDK_Up, GDK_Down, GDK_Left,
-			GDK_Right);
-	if (numworms > 1) 
-		worms[1] = gnibbles_worm_new (WORMGRAY, GDK_w, GDK_s, GDK_a,
-				GDK_d);
-				*/
 }
 
 void gnibbles_destroy ()
@@ -403,8 +399,8 @@ gint gnibbles_move_worms ()
 		status &= !dead[i];
 	}
 
-	// If one worm has died, me must make sure that an earlier worm was not
-	// supposed to die as well.
+	/* If one worm has died, me must make sure that an earlier worm was not
+	   supposed to die as well. */
 
 	if (!status)
 		for (i = 0; i < properties->numworms; i++)
@@ -418,9 +414,11 @@ gint gnibbles_move_worms ()
 					gnibbles_draw_pixmap (BLANKPIXMAP,
 							worms[i]->xtail,
 							worms[i]->ytail);
-					gnibbles_draw_pixmap (worms[i]->pixmap,
-							worms[i]->xhead,
-							worms[i]->yhead);
+					gnibbles_draw_pixmap
+						(properties->wormprops[i]
+						 ->color,
+						 worms[i]->xhead,
+						 worms[i]->yhead);
 				}
 
 	for (i = 0; i < properties->numworms; i++)
@@ -438,15 +436,15 @@ gint gnibbles_move_worms ()
 			gnibbles_worm_draw_head (worms[i]);
 
 	if (status & GAMEOVER) {
-		gnome_triggers_do (NULL, NULL, "gnibbles", "crash", NULL);
-		gnome_triggers_do (NULL, NULL, "gnibbles", "gameover", NULL);
+		gnibbles_play_sound ("crash");
+		gnibbles_play_sound ("gameover");
 		return (GAMEOVER);
 	}
 
 	if (status)
 		return (CONTINUE);
 
-	gnome_triggers_do (NULL, NULL, "gnibbles", "crash", NULL);
+	gnibbles_play_sound ("crash");
 	return (NEWROUND);
 }
 
@@ -465,3 +463,39 @@ void gnibbles_undraw_worms (gint data)
 	for (i = 0; i < properties->numworms; i++)
 		gnibbles_worm_undraw_nth (worms[i], data);
 }
+
+void gnibbles_play_sound (const char *which)
+{
+	if (properties->sound)
+		gnome_triggers_do (NULL, NULL, "gnibbles", which, NULL);
+}
+
+void gnibbles_show_scores (gint pos)
+{
+	char buf[10];
+
+	sprintf (buf, "%d.%d", properties->gamespeed, properties->fakes);
+
+	gnome_scores_display ("Gnibbles", "gnibbles", buf, pos);
+}
+
+void gnibbles_log_score ()
+{
+	char buf[10];
+	int pos;
+	
+	if (properties->numworms > 1)
+		return;
+
+	if (properties->startlevel != 1)
+		return;
+
+	if (!worms[0]->score)
+		return;
+
+	sprintf (buf, "%d.%d", properties->gamespeed, properties->fakes);
+
+	pos = gnome_score_log (worms[0]->score, buf, TRUE);
+
+	gnibbles_show_scores (pos);
+}
