@@ -1,3 +1,22 @@
+/* 
+ *   Gnome Nibbles: Gnome Worm Game
+ *   Written by Sean MacIsaac <sjm@acm.org>, Ian Peters <itp@gnu.org>
+ * 
+ *   This program is free software; you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation; either version 2 of the License, or
+ *   (at your option) any later version.
+ *
+ *   This program is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *   GNU General Public License for more details.
+ *
+ *   You should have received a copy of the GNU General Public License
+ *   along with this program; if not, write to the Free Software
+ *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
+
 #include <config.h>
 #include <gnome.h>
 #include <gdk/gdkkeysyms.h>
@@ -42,16 +61,19 @@ static gint main_loop (gpointer data);
 static gint add_bonus_cb (gpointer data);
 static void render_logo ();
 static gint new_game_cb (GtkWidget *widget, gpointer data);
-static gint pause_game_cb (GtkWidget *widget, gpointer data);
+gint pause_game_cb (GtkWidget *widget, gpointer data);
 static gint end_game_cb (GtkWidget *widget, gpointer data);
 static void quit_cb (GtkWidget *widget, gpointer data);
 static void about_cb (GtkWidget *widget, gpointer data);
+static gint show_scores_cb (GtkWidget *widget, gpointer data);
 
 static GnomeUIInfo game_menu[] = {
 	GNOMEUIINFO_MENU_NEW_GAME_ITEM (new_game_cb, NULL),
 	GNOMEUIINFO_MENU_PAUSE_GAME_ITEM (pause_game_cb, NULL),
 	GNOMEUIINFO_SEPARATOR,
+	GNOMEUIINFO_MENU_SCORES_ITEM (show_scores_cb, NULL),
 	GNOMEUIINFO_MENU_END_GAME_ITEM (end_game_cb, (gpointer) 2),
+	GNOMEUIINFO_SEPARATOR,
 	GNOMEUIINFO_MENU_EXIT_ITEM (quit_cb, NULL),
 	GNOMEUIINFO_END
 };
@@ -74,7 +96,7 @@ static GnomeUIInfo main_menu[] = {
 	GNOMEUIINFO_END
 };
 
-static gint game_running ()
+gint game_running ()
 {
 	return (main_id || erase_id || dummy_id || restart_id || paused);
 }
@@ -137,8 +159,11 @@ static void about_cb (GtkWidget *widget, gpointer data)
 		return;
 	}
 
-	about = gnome_about_new (_("Gnibbles"), VERSION, "(C) 1999 Sean MacIsaac and Ian Peters", (const char **)authors,
-			_("Send comments and bug reports to: sjm@acm.org, ipeters@acm.org"), NULL);
+	about = gnome_about_new (_("Gnibbles"), VERSION,
+			"(C) 1999 Sean MacIsaac and Ian Peters",
+			(const char **)authors,
+			_("Send comments and bug reports to: sjm@acm.org, itp@gnu.org"),
+			NULL);
 	gtk_signal_connect (GTK_OBJECT (about), "destroy", GTK_SIGNAL_FUNC
 			(gtk_widget_destroyed), &about);
 	gnome_dialog_set_parent (GNOME_DIALOG (about), GTK_WINDOW (window));
@@ -185,8 +210,10 @@ static gint new_game_2_cb (GtkWidget *widget, gpointer data)
 static gint new_game_cb (GtkWidget *widget, gpointer data)
 {
 	gtk_widget_set_sensitive (game_menu[1].widget, TRUE);
-	gtk_widget_set_sensitive (game_menu[3].widget, TRUE);
+	gtk_widget_set_sensitive (game_menu[4].widget, TRUE);
+	/*
 	gtk_widget_set_sensitive (settings_menu[0].widget, FALSE);
+	*/
 
 	if (game_running ()) {
 		if (!end_game_box ()) {
@@ -227,12 +254,10 @@ static gint new_game_cb (GtkWidget *widget, gpointer data)
 	if (dummy_id)
 		gtk_timeout_remove (dummy_id);
 
-	gnome_triggers_do (NULL, NULL, "gnibbles", "startgame", NULL);
-
 	dummy_id = gtk_timeout_add (1500, (GtkFunction) new_game_2_cb, NULL);
 }
 
-static gint pause_game_cb (GtkWidget *widget, gpointer data)
+gint pause_game_cb (GtkWidget *widget, gpointer data)
 {
 	if (paused) {
 		paused = 0;
@@ -269,6 +294,11 @@ static gint pause_game_cb (GtkWidget *widget, gpointer data)
 	}
 }
 
+static gint show_scores_cb (GtkWidget *widget, gpointer data)
+{
+	gnibbles_show_scores (0);
+}
+
 static gint end_game_cb (GtkWidget *widget, gpointer data)
 {
 	if ((gint) data == 2)
@@ -308,8 +338,10 @@ static gint end_game_cb (GtkWidget *widget, gpointer data)
 	if ((gint) data) {
 		render_logo ();
 		gtk_widget_set_sensitive (game_menu[1].widget, FALSE);
-		gtk_widget_set_sensitive (game_menu[3].widget, FALSE);
+		gtk_widget_set_sensitive (game_menu[4].widget, FALSE);
+		/*
 		gtk_widget_set_sensitive (settings_menu[0].widget, TRUE);
+		*/
 	}
 
 	paused = 0;
@@ -333,8 +365,6 @@ static gint restart_game (gpointer data)
 	dummy_id = gtk_timeout_add (1500, (GtkFunction) new_game_2_cb,
 			NULL);
 
-	gnome_triggers_do (NULL, NULL, "gnibbles", "startgame", NULL);
-
 	restart_id = 0;
 
 	return (FALSE);
@@ -374,6 +404,7 @@ static gint main_loop (gpointer data)
 		erase_id = gtk_timeout_add (3000,
 				(GtkFunction) erase_worms_cb,
 				(gpointer) ERASESIZE);
+		gnibbles_log_score ();
 		return (FALSE);
 	}
 
@@ -454,8 +485,9 @@ static void setup_window ()
 
 	gnome_app_create_menus (GNOME_APP (window), main_menu);
 
-	appbar = gnome_appbar_new (FALSE, TRUE, FALSE);
+	appbar = gnome_appbar_new (FALSE, TRUE, GNOME_PREFERENCES_USER);
 	gnome_app_set_statusbar (GNOME_APP (window), appbar);
+	gnome_app_install_menu_hints (GNOME_APP (window), main_menu);
 
 	scoreboard = gnibbles_scoreboard_new (appbar);
 }
@@ -484,8 +516,8 @@ static void render_logo ()
 
 	gdk_draw_pixmap (buffer_pixmap,
 			drawing_area->style->fg_gc[GTK_WIDGET_STATE
-			(drawing_area)], logo_pixmap, 0, 0, 160, 220, 600,
-			200);
+			(drawing_area)], logo_pixmap, 0, 0, 85, 205, 750,
+			250);
 
 	gdk_draw_pixmap (drawing_area->window,
 			drawing_area->style->fg_gc[GTK_WIDGET_STATE
@@ -496,6 +528,8 @@ static void render_logo ()
 int main (int argc, char **argv)
 {
 	gint foo;
+
+	gnome_score_init ("gnibbles");
 	
 	gnome_init ("Gnibbles", VERSION, argc, argv);
 
@@ -518,7 +552,7 @@ int main (int argc, char **argv)
 	set_bg_color ();
 
 	gtk_widget_set_sensitive (game_menu[1].widget, FALSE);
-	gtk_widget_set_sensitive (game_menu[3].widget, FALSE);
+	gtk_widget_set_sensitive (game_menu[4].widget, FALSE);
 
 	gtk_main ();
 
