@@ -1,6 +1,6 @@
 /*
  * gnothello.c - Main GUI part of iagno
- * written by Ian Peters <ipeters@acm.org>
+ * written by Ian Peters <itp@gnu.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -394,7 +394,8 @@ void about_cb(GtkWidget *widget, gpointer data)
 		return;
 	}
 
-	about = gnome_about_new(_("Iagno"), VERSION, "(C) 1998 Ian Peters", (const char **)authors, _("Send comments and bug reports to: ipeters@acm.org\nTiles under the General Public License."), NULL);
+	about = gnome_about_new(_("Iagno"), VERSION, "(C) 1998 Ian Peters",
+			(const char **)authors, _("Send comments and bug reports to: itp@acm.org\nTiles under the General Public License."), NULL);
 	gtk_signal_connect (GTK_OBJECT (about), "destroy", GTK_SIGNAL_FUNC
 			(gtk_widget_destroyed), &about);
 	gnome_dialog_set_parent(GNOME_DIALOG(about), GTK_WINDOW(window));
@@ -650,10 +651,8 @@ void create_window()
 	gnome_app_install_menu_hints(GNOME_APP (window), mainmenu);
 
 	table = gtk_table_new(1, 8, FALSE);
-//	gtk_table_set_col_spacing(GTK_TABLE(table), 1, 32);
-//	gtk_table_set_col_spacing(GTK_TABLE(table), 2, 32);
 
-	black_score = gtk_label_new("Dark:");
+	black_score = gtk_label_new(_("Dark:"));
 	gtk_widget_show(black_score);
 
 	gtk_table_attach(GTK_TABLE(table), black_score, 1, 2, 0, 1, 0, 0, 3, 1);
@@ -668,7 +667,7 @@ void create_window()
 
 	gtk_table_attach(GTK_TABLE(table), sep, 3, 4, 0, 1, 0, GTK_FILL, 3, 3);
 
-	white_score = gtk_label_new("Light:");
+	white_score = gtk_label_new(_("Light:"));
 	gtk_widget_show(white_score);
 
 	gtk_table_attach(GTK_TABLE(table), white_score, 4, 5, 0, 1, 0, 0, 3, 1);
